API documentation
=================

.. currentmodule:: helical.models
.. automodule:: helical.models


.. autosummary::
   :toctree: _autosummary


   helical.models.uce.model.UCE
   helical.models.geneformer.model.Geneformer

   .. helical.models.helical.HelicalBaseFoundationModel
   .. helical.models.uce.model.UCE
   .. helical.models.geneformer.model.Geneformer
   .. helical.models.scgpt.model

.. UCE Model
.. --------
.. .. autofunction:: helical.models.uce.model.UCE

.. Geneformer Model
.. --------
.. .. autofunction:: helical.models.geneformer.model.Geneformer

.. SCGPT Model
.. --------
.. .. autofunction:: helical.models.geneformer.model.scgpt